@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: common.h,v 1.3 2007/07/10 05:04:03 arcanum Exp $ */
+/* $Id: common.h,v 1.3.4.4 2009/03/02 23:36:17 arcanum Exp $ */
 
 
 #ifndef _AVR_COMMON_H
@@ -65,14 +65,22 @@ All other architectures do have a stack pointer.  Some devices have only
 less than 256 bytes of possible RAM locations (128 Bytes of SRAM
 and no option for external RAM), thus SPH is officially "reserved"
 for them.
-
 */
-#if __AVR_ARCH__ != 1
-
+#if __AVR_ARCH__ >= 100
+#  ifndef SPL
+#    define SPL _SFR_MEM8(0x3D)
+#  endif
+#  ifndef SPH
+#    define SPH _SFR_MEM8(0x3E)
+#  endif
+#  ifndef SP
+#    define SP _SFR_MEM16(0x3D)
+#  endif
+#elif __AVR_ARCH__ != 1 
 #  ifndef SPL
 #    define SPL _SFR_IO8(0x3D)
 #  endif
-#  if XRAMEND < 0x100
+#  if XRAMEND < 0x100 && !defined(__COMPILING_AVR_LIBC__)
 #    ifndef SP
 #      define SP  _SFR_IO8(0x3D)
 #    endif
@@ -84,15 +92,19 @@ for them.
 #      define SPH _SFR_IO8(0x3E)
 #    endif
 #  endif /* XRAMEND < 0x100 && !defined(__COMPILING_AVR_LIBC__) */
-
 #endif /* __AVR_ARCH__ != 1 */
 
 
 /* Status Register */
 #ifndef SREG
-#  define SREG _SFR_IO8(0x3F)
+#  if __AVR_ARCH__ >= 100
+#    define SREG _SFR_MEM8(0x3F)
+#  else
+#    define SREG _SFR_IO8(0x3F)
+#  endif
 #endif
 
+
 /* SREG bit definitions */
 #ifndef SREG_C
 #  define SREG_C  (0)
@@ -120,17 +132,20 @@ for them.
 #endif
 
 
-/* AVR 6 Architecture */
-#if __AVR_ARCH__ == 6
-#  ifndef EIND
-#    define EIND  _SFR_IO8(0X3C)
-#  endif
-#endif /* __AVR_ARCH__ == 6 */
-
-
-
 #if defined(__COMPILING_AVR_LIBC__)
 
+/* AVR 6 Architecture */
+#  if __AVR_ARCH__ == 6
+#    ifndef EIND
+#      define EIND  _SFR_IO8(0X3C)
+#    endif
+/* XMEGA Architectures */
+#  elif __AVR_ARCH__ >= 100
+#    ifndef EIND
+#      define EIND  _SFR_MEM8(0x3C)
+#    endif
+#  endif
+
 /*
 Only few devices come without EEPROM.  In order to assemble the
 EEPROM library components without defining a specific device, we
@@ -197,39 +212,112 @@ and families.
 /* Status Register */
 #if defined(SREG)
 #  define AVR_STATUS_REG   SREG
-#  define AVR_STATUS_ADDR  _SFR_IO_ADDR(SREG)
+#  if __AVR_ARCH__ >= 100
+#    define AVR_STATUS_ADDR  _SFR_MEM_ADDR(SREG)
+#  else
+#    define AVR_STATUS_ADDR  _SFR_IO_ADDR(SREG)
+#  endif
 #endif
 
 /* Stack Pointer (combined) Register */
 #if defined(SP)
 #  define AVR_STACK_POINTER_REG   SP
-#  define AVR_STACK_POINTER_ADDR  _SFR_IO_ADDR(SP)
+#  if __AVR_ARCH__ >= 100
+#    define AVR_STACK_POINTER_ADDR  _SFR_MEM_ADDR(SP)
+#  else
+#    define AVR_STACK_POINTER_ADDR  _SFR_IO_ADDR(SP)
+#  endif
 #endif
 
 /* Stack Pointer High Register */
 #if defined(SPH)
 #  define _HAVE_AVR_STACK_POINTER_HI 1
 #  define AVR_STACK_POINTER_HI_REG   SPH
-#  define AVR_STACK_POINTER_HI_ADDR  _SFR_IO_ADDR(SPH)
+#  if __AVR_ARCH__ >= 100
+#    define AVR_STACK_POINTER_HI_ADDR  _SFR_MEM_ADDR(SPH)
+#  else
+#    define AVR_STACK_POINTER_HI_ADDR  _SFR_IO_ADDR(SPH)
+#  endif
 #endif
 
 /* Stack Pointer Low Register */
 #if defined(SPL)
 #  define AVR_STACK_POINTER_LO_REG   SPL
-#  define AVR_STACK_POINTER_LO_ADDR  _SFR_IO_ADDR(SPL)
+#  if __AVR_ARCH__ >= 100
+#    define AVR_STACK_POINTER_LO_ADDR  _SFR_MEM_ADDR(SPL)
+#  else
+#    define AVR_STACK_POINTER_LO_ADDR  _SFR_IO_ADDR(SPL)
+#  endif
+#endif
+
+/* RAMPD Register */
+#if defined(RAMPD)
+#  define AVR_RAMPD_REG   RAMPD
+#  if __AVR_ARCH__ >= 100
+#    define AVR_RAMPD_ADDR  _SFR_MEM_ADDR(RAMPD)
+#  else
+#    define AVR_RAMPD_ADDR  _SFR_IO_ADDR(RAMPD)
+#  endif
+#endif
+
+/* RAMPX Register */
+#if defined(RAMPX)
+#  define AVR_RAMPX_REG   RAMPX
+#  if __AVR_ARCH__ >= 100
+#    define AVR_RAMPX_ADDR  _SFR_MEM_ADDR(RAMPX)
+#  else
+#    define AVR_RAMPX_ADDR  _SFR_IO_ADDR(RAMPX)
+#  endif
+#endif
+
+/* RAMPY Register */
+#if defined(RAMPY)
+#  define AVR_RAMPY_REG   RAMPY
+#  if __AVR_ARCH__ >= 100
+#    define AVR_RAMPY_ADDR  _SFR_MEM_ADDR(RAMPY)
+#  else
+#    define AVR_RAMPY_ADDR  _SFR_IO_ADDR(RAMPY)
+#  endif
 #endif
 
 /* RAMPZ Register */
 #if defined(RAMPZ)
 #  define AVR_RAMPZ_REG   RAMPZ
-#  define AVR_RAMPZ_ADDR  _SFR_IO_ADDR(RAMPZ)
+#  if __AVR_ARCH__ >= 100
+#    define AVR_RAMPZ_ADDR  _SFR_MEM_ADDR(RAMPZ)
+#  else
+#    define AVR_RAMPZ_ADDR  _SFR_IO_ADDR(RAMPZ)
+#  endif
 #endif
 
 /* Extended Indirect Register */
 #if defined(EIND)
 #  define AVR_EXTENDED_INDIRECT_REG   EIND
-#  define AVR_EXTENDED_INDIRECT_ADDR  _SFR_IO_ADDR(EIND)
+#  if __AVR_ARCH__ >= 100
+#    define AVR_EXTENDED_INDIRECT_ADDR  _SFR_MEM_ADDR(EIND)
+#  else
+#    define AVR_EXTENDED_INDIRECT_ADDR  _SFR_IO_ADDR(EIND)
+#  endif
 #endif
 
+/*------------ Workaround to old compilers (4.1.2 and earlier)  ------------*/
+
+#ifndef __AVR_HAVE_MOVW__
+# if  defined(__AVR_ENHANCED__) && __AVR_ENHANCED__
+#  define __AVR_HAVE_MOVW__ 1
+# endif
+#endif
+
+#ifndef __AVR_HAVE_LPMX__
+# if  defined(__AVR_ENHANCED__) && __AVR_ENHANCED__
+#  define __AVR_HAVE_LPMX__ 1
+# endif
+#endif
+
+#ifndef __AVR_HAVE_MUL__
+# if  defined(__AVR_ENHANCED__) && __AVR_ENHANCED__
+#  define __AVR_HAVE_MUL__ 1
+# endif
+#endif
 
 #endif /* _AVR_COMMON_H */
