@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iousb162.h,v 1.2 2007/12/12 04:36:56 arcanum Exp $ */
+/* $Id: iousb162.h,v 1.2.2.5 2009/02/11 18:05:34 arcanum Exp $ */
 
 /* avr/iousb162.h - definitions for AT90USB162 */
 
@@ -38,44 +38,44 @@
 #include <avr/iousbxx2.h>
 
 /* Constants */
-#define SPM_PAGESIZE    128
-#define RAMEND          0x2FF
-#define XRAMEND         0x2FF
-#define E2END           0x1FF
-#define FLASHEND        0x3FFF
+#define SPM_PAGESIZE 128
+#define RAMEND       0x2FF
+#define XRAMEND      RAMEND
+#define E2END        0x1FF
+#define E2PAGESIZE   4
+#define FLASHEND     0x3FFF
 
 
 /* Fuses */
-
 #define FUSE_MEMORY_SIZE 3
 
 /* Low Fuse Byte */
-#define CKSEL0      ~_BV(0)
-#define CKSEL1      ~_BV(1)
-#define CKSEL2      ~_BV(2)
-#define CKSEL3      ~_BV(3)
-#define SUT0        ~_BV(4)
-#define SUT1        ~_BV(5)
-#define CKOUT       ~_BV(6)
-#define CKDIV8      ~_BV(7)
+#define FUSE_CKSEL0      (unsigned char)~_BV(0)
+#define FUSE_CKSEL1      (unsigned char)~_BV(1)
+#define FUSE_CKSEL2      (unsigned char)~_BV(2)
+#define FUSE_CKSEL3      (unsigned char)~_BV(3)
+#define FUSE_SUT0        (unsigned char)~_BV(4)
+#define FUSE_SUT1        (unsigned char)~_BV(5)
+#define FUSE_CKOUT       (unsigned char)~_BV(6)
+#define FUSE_CKDIV8      (unsigned char)~_BV(7)
 #define LFUSE_DEFAULT (CKSEL0 & SUT1 & CKDIV8)
 
 /* High Fuse Byte */
-#define BOOTRST     ~_BV(0)
-#define BOOTSZ0     ~_BV(1)
-#define BOOTSZ1     ~_BV(2)
-#define EESAVE      ~_BV(3)
-#define WDTON       ~_BV(4)
-#define SPIEN       ~_BV(5)
-#define RSTDSBL     ~_BV(6)
-#define DWEN        ~_BV(7)
+#define FUSE_BOOTRST     (unsigned char)~_BV(0)
+#define FUSE_BOOTSZ0     (unsigned char)~_BV(1)
+#define FUSE_BOOTSZ1     (unsigned char)~_BV(2)
+#define FUSE_EESAVE      (unsigned char)~_BV(3)
+#define FUSE_WDTON       (unsigned char)~_BV(4)
+#define FUSE_SPIEN       (unsigned char)~_BV(5)
+#define FUSE_RSTDSBL     (unsigned char)~_BV(6)
+#define FUSE_DWEN        (unsigned char)~_BV(7)
 #define HFUSE_DEFAULT (BOOTSZ0 & BOOTSZ1 & SPIEN)
 
 /* Extended Fuse Byte */
-#define BODLEVEL0   ~_BV(0)
-#define BODLEVEL1   ~_BV(1)
-#define BODLEVEL2   ~_BV(2)
-#define HWBE        ~_BV(3)
+#define FUSE_BODLEVEL0   (unsigned char)~_BV(0)
+#define FUSE_BODLEVEL1   (unsigned char)~_BV(1)
+#define FUSE_BODLEVEL2   (unsigned char)~_BV(2)
+#define FUSE_HWBE        (unsigned char)~_BV(3)
 #define EFUSE_DEFAULT (BODLEVEL0 & BODLEVEL1 & HWBE)
 
 
@@ -85,4 +85,10 @@
 #define __BOOT_LOCK_BITS_1_EXIST 
 
 
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x94
+#define SIGNATURE_2 0x82
+
+
 #endif /* _AVR_AT90USB162_H_ */
